/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Akonadi.Imap.Settings.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef IMAPRESOURCESETTINGS_H
#define IMAPRESOURCESETTINGS_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Akonadi.Imap.Settings
 */
class OrgKdeAkonadiImapSettingsInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Akonadi.Imap.Settings"; }

public:
    OrgKdeAkonadiImapSettingsInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeAkonadiImapSettingsInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<int> accountIdentity()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("accountIdentity"), argumentList);
    }

    inline QDBusPendingReply<int> alternateAuthentication()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("alternateAuthentication"), argumentList);
    }

    inline QDBusPendingReply<int> authentication()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("authentication"), argumentList);
    }

    inline QDBusPendingReply<bool> automaticExpungeEnabled()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("automaticExpungeEnabled"), argumentList);
    }

    inline QDBusPendingReply<bool> disconnectedModeEnabled()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("disconnectedModeEnabled"), argumentList);
    }

    inline QDBusPendingReply<QStringList> idleRidPath()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("idleRidPath"), argumentList);
    }

    inline QDBusPendingReply<int> imapPort()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("imapPort"), argumentList);
    }

    inline QDBusPendingReply<QString> imapServer()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("imapServer"), argumentList);
    }

    inline QDBusPendingReply<bool> intervalCheckEnabled()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("intervalCheckEnabled"), argumentList);
    }

    inline QDBusPendingReply<int> intervalCheckTime()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("intervalCheckTime"), argumentList);
    }

    inline QDBusPendingReply<QStringList> knownMailBoxes()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("knownMailBoxes"), argumentList);
    }

    inline QDBusPendingReply<QString> overrideEncryption()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("overrideEncryption"), argumentList);
    }

    inline QDBusPendingReply<bool> retrieveMetadataOnFolderListing()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("retrieveMetadataOnFolderListing"), argumentList);
    }

    inline QDBusPendingReply<QString> safety()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("safety"), argumentList);
    }

    inline QDBusPendingReply<> save()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("save"), argumentList);
    }

    inline QDBusPendingReply<int> sessionTimeout()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sessionTimeout"), argumentList);
    }

    inline QDBusPendingReply<> setAccountIdentity(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setAccountIdentity"), argumentList);
    }

    inline QDBusPendingReply<> setAlternateAuthentication(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setAlternateAuthentication"), argumentList);
    }

    inline QDBusPendingReply<> setAuthentication(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setAuthentication"), argumentList);
    }

    inline QDBusPendingReply<> setAutomaticExpungeEnabled(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setAutomaticExpungeEnabled"), argumentList);
    }

    inline QDBusPendingReply<> setDisconnectedModeEnabled(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setDisconnectedModeEnabled"), argumentList);
    }

    inline QDBusPendingReply<> setIdleRidPath(const QStringList &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setIdleRidPath"), argumentList);
    }

    inline QDBusPendingReply<> setImapPort(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setImapPort"), argumentList);
    }

    inline QDBusPendingReply<> setImapServer(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setImapServer"), argumentList);
    }

    inline QDBusPendingReply<> setIntervalCheckEnabled(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setIntervalCheckEnabled"), argumentList);
    }

    inline QDBusPendingReply<> setIntervalCheckTime(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setIntervalCheckTime"), argumentList);
    }

    inline QDBusPendingReply<> setKnownMailBoxes(const QStringList &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setKnownMailBoxes"), argumentList);
    }

    inline QDBusPendingReply<> setOverrideEncryption(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setOverrideEncryption"), argumentList);
    }

    inline QDBusPendingReply<> setRetrieveMetadataOnFolderListing(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setRetrieveMetadataOnFolderListing"), argumentList);
    }

    inline QDBusPendingReply<> setSafety(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSafety"), argumentList);
    }

    inline QDBusPendingReply<> setSessionTimeout(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSessionTimeout"), argumentList);
    }

    inline QDBusPendingReply<> setSieveAlternateUrl(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSieveAlternateUrl"), argumentList);
    }

    inline QDBusPendingReply<> setSieveCustomAuthentification(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSieveCustomAuthentification"), argumentList);
    }

    inline QDBusPendingReply<> setSieveCustomUsername(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSieveCustomUsername"), argumentList);
    }

    inline QDBusPendingReply<> setSievePort(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSievePort"), argumentList);
    }

    inline QDBusPendingReply<> setSieveReuseConfig(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSieveReuseConfig"), argumentList);
    }

    inline QDBusPendingReply<> setSieveSupport(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSieveSupport"), argumentList);
    }

    inline QDBusPendingReply<> setSieveVacationFilename(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSieveVacationFilename"), argumentList);
    }

    inline QDBusPendingReply<> setSubscriptionEnabled(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setSubscriptionEnabled"), argumentList);
    }

    inline QDBusPendingReply<> setTrashCollection(qlonglong in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setTrashCollection"), argumentList);
    }

    inline QDBusPendingReply<> setTrashCollectionMigrated(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setTrashCollectionMigrated"), argumentList);
    }

    inline QDBusPendingReply<> setUseDefaultIdentity(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setUseDefaultIdentity"), argumentList);
    }

    inline QDBusPendingReply<> setUserName(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setUserName"), argumentList);
    }

    inline QDBusPendingReply<QString> sieveAlternateUrl()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sieveAlternateUrl"), argumentList);
    }

    inline QDBusPendingReply<QString> sieveCustomAuthentification()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sieveCustomAuthentification"), argumentList);
    }

    inline QDBusPendingReply<QString> sieveCustomUsername()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sieveCustomUsername"), argumentList);
    }

    inline QDBusPendingReply<int> sievePort()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sievePort"), argumentList);
    }

    inline QDBusPendingReply<bool> sieveReuseConfig()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sieveReuseConfig"), argumentList);
    }

    inline QDBusPendingReply<bool> sieveSupport()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sieveSupport"), argumentList);
    }

    inline QDBusPendingReply<QString> sieveVacationFilename()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sieveVacationFilename"), argumentList);
    }

    inline QDBusPendingReply<bool> subscriptionEnabled()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("subscriptionEnabled"), argumentList);
    }

    inline QDBusPendingReply<qlonglong> trashCollection()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("trashCollection"), argumentList);
    }

    inline QDBusPendingReply<bool> trashCollectionMigrated()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("trashCollectionMigrated"), argumentList);
    }

    inline QDBusPendingReply<bool> useDefaultIdentity()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("useDefaultIdentity"), argumentList);
    }

    inline QDBusPendingReply<QString> userName()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("userName"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace Akonadi {
      namespace Imap {
        using Settings = ::OrgKdeAkonadiImapSettingsInterface;
      }
    }
  }
}

#endif
