// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PIMCOMMONACTIVITIES_VERSION_H
#define PIMCOMMONACTIVITIES_VERSION_H

#define PIMCOMMONACTIVITIES_VERSION_STRING "6.7.1"
#define PIMCOMMONACTIVITIES_VERSION_MAJOR 6
#define PIMCOMMONACTIVITIES_VERSION_MINOR 7
#define PIMCOMMONACTIVITIES_VERSION_PATCH 1
#define PIMCOMMONACTIVITIES_VERSION ((6<<16)|(7<<8)|(1))

#endif
